#
# spec file for package javaparser
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           javaparser
Version:        3.25.1
Release:        150200.3.7.11
Summary:        Java 1 to 15 Parser and Abstract Syntax Tree for Java
License:        Apache-2.0 OR LGPL-3.0-or-later
Group:          Development/Libraries/Java
URL:            https://javaparser.org
Source0:        https://github.com/javaparser/javaparser/archive/%{name}-parent-%{version}.tar.gz
BuildRequires:  fdupes
BuildRequires:  maven-local
BuildRequires:  mvn(biz.aQute.bnd:bnd-maven-plugin)
BuildRequires:  mvn(javax.annotation:javax.annotation-api)
BuildRequires:  mvn(net.java.dev.javacc:javacc)
BuildRequires:  mvn(org.checkerframework:checker-qual)
BuildRequires:  mvn(org.codehaus.mojo:build-helper-maven-plugin)
BuildRequires:  mvn(org.codehaus.mojo:javacc-maven-plugin)
BuildRequires:  mvn(org.javassist:javassist)
BuildArch:      noarch

%description
A set of libraries implementing a Java 1.0 - Java 15 Parser with advanced
analysis functionalities. This includes preview features to Java 13, with Java
14 preview features work-in-progress.

%package javadoc
Summary:        Javadoc for %{name}

%description javadoc
This package contains API documentation for %{name}.

%prep
%setup -q -n %{name}-%{name}-parent-%{version}

sed -i 's/\r//' readme.md

# Remove plugins unnecessary for RPM builds
%pom_remove_plugin -r :jacoco-maven-plugin
%pom_remove_plugin :maven-source-plugin
%pom_remove_plugin :coveralls-maven-plugin

%pom_add_dep org.checkerframework:checker-qual javaparser-symbol-solver-core

# Compatibility alias
%{mvn_alias} :javaparser-core com.google.code.javaparser:javaparser

# Fix javacc plugin name
sed -i \
  -e 's/ph-javacc-maven-plugin/javacc-maven-plugin/' \
  -e 's/com.helger.maven/org.codehaus.mojo/' \
  javaparser-core/pom.xml

# This plugin is not packaged, so use maven-resources-plugin to accomplish the same thing
%pom_remove_plugin :templating-maven-plugin javaparser-core
%pom_xpath_inject "pom:build" "
<resources>
  <resource>
    <directory>src/main/java-templates</directory>
    <filtering>true</filtering>
    <targetPath>\${basedir}/src/main/java</targetPath>
  </resource>
</resources>" javaparser-core

# Missing dep on jbehave for testing
%pom_disable_module javaparser-core-testing
%pom_disable_module javaparser-core-testing-bdd

# Only need to ship the core module
%pom_disable_module javaparser-core-generators
%pom_disable_module javaparser-core-metamodel-generator
%pom_disable_module javaparser-core-serialization

%build
%{mvn_build} -f -- -Dsource=8

%install
%mvn_install
%fdupes -s %{buildroot}%{_javadocdir}

%files -f .mfiles
%doc readme.md changelog.md
%license LICENSE LICENSE.APACHE LICENSE.GPL LICENSE.LGPL

%files javadoc -f .mfiles-javadoc
%license LICENSE LICENSE.APACHE LICENSE.GPL LICENSE.LGPL

%changelog
* Wed Mar  8 2023 shvetz.anton@gmail.com
- Upgrade to upstream version 3.25.1
  * API or Behaviour Change
    + Fix: Issue 3045 Unexpected exception when solving type inside
    an Anonymous class (PR #3896 by @jlerbsc)
  * Added
    + Improved search for functional interfaces (PR #3894 by
    @jlerbsc)
  * Changed
    + chore(deps): bump maven-compiler-plugin from 3.10.1 to 3.11.0
    (PR #3928 by @dependabot[bot])
    + chore(deps): bump checkstyle from 10.7.0 to 10.8.0 (PR #3927
    by @dependabot[bot])
    + chore(deps): bump versions-maven-plugin from 2.14.2 to 2.15.0
    (PR #3914 by @dependabot[bot])
    + chore(deps): bump maven-javadoc-plugin from 3.4.1 to 3.5.0
    (PR #3906 by @dependabot[bot])
    + Refactor: cleanup/refactor code after fixing #3859 (PR #3886
    by @abego)
  * Fixed
    + Fix: issue 3924 Removing ImportDeclaration with Annotated
    package thr… (PR #3926 by @jlerbsc)
    + Fix: issue 3918 JavaParserTypeDeclarationAdapter resolving
    wrong Type via Ancestor (PR #3921 by @jlerbsc)
    + Fix: issue 3919 ResolvedType::isAssignableBy(ResolvedType) is
    wrong f… (PR #3920 by @jlerbsc)
    + Fix: issue 3911 java.lang.UnsupportedOperationException: T[]
    while resolving generic method with type parameter with
    arrays like List<T[]> (PR #3917 by @jlerbsc)
    + Fix: \s escape gives lexical error but should be valid since
    Java 15 (PR #3903 by @jlerbsc)
    + Fix: Issue 3045 Unexpected exception when solving type inside
    an Anonymous class (PR #3896 by @jlerbsc)
    + Fix issue 1883 Finding lambda return type (PR #3890 by
    @jlerbsc)
    + Fix: issue 1815 ArrayIndexOutOfBoundsException when resolving
    lambda parameter. This fix is offered by Blackgen (PR #3888
    by @jlerbsc)
  * Developer Changes
    + chore(deps): bump checkstyle from 10.6.0 to 10.7.0 (PR #3885
    by @dependabot[bot])
- Upgrade to upstream version 3.25.0
  * Added
    + First part of the implementation of least upper bound logic
    (PR #3880 by @jlerbsc)
    + feat: Improved support for calculating the type of an object
    creation… (PR #3877 by @jlerbsc)
    + feat: Implement addRecord & getRecordByName for
    CompilationUnit (PR #3836 by @marcluque)
    + Support Jigsaw requires static (PR #3826 by @jlerbsc)
    + Add toDescriptor to ResolvedMethodDeclaration (PR #3819 by
    @vanHekthor)
    + Refactoring context (WIP) (PR #3792 by @jlerbsc)
    + Refactoring context (WIP) (PR #3782 by @jlerbsc)
    + Refactoring convert to usage (PR #3774 by @jlerbsc)
    + Simplified usage of class AssociableToAST (PR #3063 by
    @4everTheOne)
  * Changed
    + Revert import related checkstyle rule from error to warning
    (PR #3881 by @jlerbsc)
    + Minor refactoring for example to get all parameter types (PR
    [#3879] by @jlerbsc)
    + Add header and footer methods in comments instead of using
    literal st… (PR #3876 by @jlerbsc)
    + In the context of lexical preservation, the CSM token must be
    added m… (PR #3874 by @jlerbsc)
    + Refactoring: remove useless code that is already implemented
    (PR #3869 by @jlerbsc)
    + Memory usage improvement when printing a node from the
    LexicalPreserv… (PR #3858 by @jlerbsc)
    + chore(deps-dev): bump assertj-core from 3.24.1 to 3.24.2 (PR
    [#3852] by @dependabot[bot])
    + chore(deps): bump maven-checkstyle-plugin from 3.2.0 to 3.2.1
    (PR #3846 by @dependabot[bot])
    + chore(deps): bump maven-dependency-plugin from 3.4.0 to 3.5.0
    (PR #3845 by @dependabot[bot])
    + chore(deps): update junit5 monorepo to v5.9.2 (PR #3840 by
    @renovate[bot])
    + Minor refactoring on Difference class (PR #3839 by @jlerbsc)
    + chore(deps-dev): bump assertj-core from 3.23.1 to 3.24.1 (PR
    [#3837] by @dependabot[bot])
    + chore(deps): bump actions/checkout from 3.2.0 to 3.3.0 (PR
    [#3834] by @dependabot[bot])
    + chore(deps): bump checkstyle from 10.5.0 to 10.6.0 (PR #3829
    by @dependabot[bot])
  * Fixed
    + Fix: Method hasScope must return true on
    NodeWithOptionalScope and No… (PR #3875 by @jlerbsc)
    + fix #3859 UnsupportedOperationException when trying to
    resolve a type… (PR #3873 by @abego)
    + Fix: issue 3866 Symbol solver is unable to resolve inner
    classes of ancestors when they are prefixed with a subclass
    (PR #3868 by @jlerbsc)
    + Fix: issue 3703 Allow removing empty parentheses after
    removing all pairs from an annotation (PR #3865 by @jlerbsc)
    + Fix: One must be able to know if any resolved type is a boxed
    primiti… (PR #3864 by @jlerbsc)
    + Fix: Issue 2374 Comments of added Nodes are ignored in
    LexicalPreserv… (PR #3856 by @jlerbsc)
    + Checkstyle for unused import (PR #3841 by @4everTheOne)
    + Update bnd file (PR #3783 by @jlerbsc)
  * Developer Changes
    + Update javaparser copyright headers (PR #3862 by @jlerbsc)
  * Uncategorised
    + Add test case to verify range calculation on ArrayType (PR
    [#3828] by @jlerbsc)
    + Add test case to verify that LexicalPreservation supports
    TextBlock (PR #3827 by @jlerbsc)
    + Refactoring: Removing useless method convertToUsage in
    JavaParserFacade (PR #3780 by @jlerbsc)
* Sat Jan 28 2023 shvetz.anton@gmail.com
- Upgrade to upstream version 3.24.10
  * Added
    + Add a method in LexicalPreservingPrinter to know if LPP is
    available/activated on the specified node (PR #3823 by
    @jlerbsc)
    + Handle nested records (PR #3814 by @mernst)
    + Source printer import ordering strategy (PR #3807 by
    @4everTheOne)
  * Changed
    + chore(deps): bump versions-maven-plugin from 2.14.1 to 2.14.2
    (PR #3817 by @dependabot[bot])
    + Enabled import validation (PR #3812 by @4everTheOne)
    + Part 5 | Import organization (PR #3805 by @4everTheOne)
    + Part 4 | Import organization (PR #3804 by @4everTheOne)
    + Part 3 | Import organization (PR #3803 by @4everTheOne)
    + Part 2 | Import organization (PR #3802 by @4everTheOne)
    + Part 1 | Import organization (PR #3801 by @4everTheOne)
    + Checkstyle configuration tweaks (PR #3799 by @4everTheOne)
    + chore(deps): bump versions-maven-plugin from 2.13.0 to 2.14.1
    (PR #3797 by @dependabot[bot])
    + chore(deps): bump actions/checkout from 3.1.0 to 3.2.0 (PR
    [#3789] by @dependabot[bot])
    + chore(deps): bump checkstyle from 8.45.1 to 10.5.0 (PR #3788
    by @dependabot[bot])
  * Fixed
    + explicit use asString for performance (PR #3821 by @dencat)
    + Fix: issue #3818 Wrong range calculation on ArrayType with
    multiple d… (PR #3820 by @jlerbsc)
    + Fix: Lexical Preserving Fails To Remove Comment (PR #3810 by
    @jlerbsc)
  * Developer Changes
    + chore(deps): bump versions-maven-plugin from 2.13.0 to 2.14.0
    (PR #3794 by @dependabot[bot])
    + Basic CheckStyle validation (PR #3781 by @4everTheOne)
  * Uncategorised
    + Fix: 3412 Remove walkmod again (PR #3806 by @jlerbsc)
* Mon Dec 12 2022 shvetz.anton@gmail.com
- Upgrade to upstream version 3.24.9
  * Highlights
    + Remove "executable" bit from code files (PR #3755 by @icmdaf)
  * Added
    + Created TypeSolverBuilder (PR #3421 by @4everTheOne)
  * Changed
    + Changing, in test classes, the initialization of the lexical
    preserva… (PR #3779 by @jlerbsc)
    + chore(deps): bump maven-dependency-plugin from 3.3.0 to 3.4.0
    (PR #3770 by @dependabot[bot])
    + chore(deps): bump maven-install-plugin from 3.0.1 to 3.1.0
    (PR #3756 by @dependabot[bot])
  * Fixed
    + Fix: #3195 Resolved methods in outer classes not inferred
    correcly (PR #3778 by @jlerbsc)
    + Fix: #3681 LineComment alwaysing trimming content (PR #3777
    by @jlerbsc)
    + Fix: #3773 Replacing nodes causes error in lexical preserving
    printer… (PR #3776 by @jlerbsc)
    + Fix: #2517 Modifying some nodes with the lexicalPreservation
    enabled … (PR #3775 by @jlerbsc)
    + Fix: #3725 JavaParserFacade var type in for-each loop cannot
    be resolved (PR #3768 by @abego)
    + Fix: #3216 LexicalPreservingPrinter add Wrong indentation
    when removing comments (PR #3766 by @jlerbsc)
    + Fix: #3472 Line comment removal causes IllegalStateException
    with LexicalPreservingPrinter (PR #3765 by @jlerbsc)
    + Fix: #3441 LexicalPreservingPrinter prints wrong output with
    line com… (PR #3764 by @jlerbsc)
    + Fix: #2137 ClassOrInterfaceDeclaration addMember using index
    (PR #3763 by @jlerbsc)
    + Fix: #3761 Lexical preserving corrupts source when adding a
    modifier in first position (PR #3762 by @jlerbsc)
    + Fix: #3693 Removing modifiers from method declaration results
    in loss… (PR #3760 by @jlerbsc)
    + Fix: #3750 Lexical preserving corrupts source (PR #3759 by
    @jlerbsc)
    + Fix: Fix the indentation generated by the
    LexicalPreservingPrinter wh… (PR #3758 by @jlerbsc)
  * Security
    + Remove "executable" bit from code files (PR #3755 by @icmdaf)
- Add build dependency on mvn(org.checkerframework:checker-qual)
* Sun Nov 27 2022 shvetz.anton@gmail.com
- Upgrade to upstream version 3.24.8
  * Added
    + [Fixes #3099] Added ability to solve type with a list of
    expected type arguments
    + [Suggestion] NonNull generator for parameters
  * Changed
    + Updated workflow to only run one job per PR
    + Remove or comment system.out.println statement in unit tests
    + Added Optional method in SymbolReference
    + Centralized management of symbol solver exceptions to prevent
    exception type Erasion
  * Fixed
    + Fix issue #1827 Issue resolving a constructor of a class
    using generics
    + Fix issue #3728 ParseProblemException
    + Updated Badge for Build and Coverage
    + Position
    + Fix part of issue #3721 UnsupportedOperationException while
    trying to modify the type of a variable
    + Implemented isReferenceType in ResolvedTypeDeclaration and
    isTypeParameter in ResolvedTypeParameterDeclaration
  * Developer Changes
    + chore(deps): bump versions-maven-plugin from 2.12.0 to 2.13.0
    + Fix maven wrapper not found in generator scripts
    + chore(deps): bump actions/checkout from 3.0.2 to 3.1.0
  * Uncategorised
    + Change issue 1945 test to paramaterized
    + More unit tests for JavaToken and CodeGenerationUtils
- Upgrade to upstream version 3.24.7
  * Highlights
    + Issue #3415
  * Changed
    + Refactoring - use of existing methods
    + Refactoring adding convenient methods to know if a
    DifferenceElement is added, removed or kept
  * Deprecated
    + Issue #3415
  * Fixed
    + Fix for ReflectionAnnotationDeclaration getClassName()
    + Fix some yield expressions not recognized
    + Accept final in instanceof pattern
    + [Fix] Avoid test failure due to line separator differences on
    windows host
    + Fix issue #3700 Removing last statement with
    LexicalPreservingPrinter results in loss of indendation
    + Fix issue #3678 Function accepts a configuration but it does
    not do anything
- Upgrade to upstream version 3.24.3
  * API or Behaviour Change
    + Issue #3405 thread safety of pre/postprocessors (incl.
    breaking change to Processor with pre/post processor
    methods).
  * Changed
    + Minor refactoring to manage check in range and use hasRange
    method in class CommentsInserter
    + Renaming PACKAGE_PRIVATE to NONE (this refers to the
    discussion in the issue #2242)
  * Fixed
    + Fix documentation of JAVA_17
    + Fix issue 3631 NameExpr.resolve() does not take end of inner
    block scopes into account
    + Fix issue #3588 Modifier is removed when removing an
    annotation
    + Fix lambda generic types that are always resolved to the
    first type param
    + Fix issue #3489 SourceRoot.tryToParse() fails if the root
    path ends with a directory that is not a java identifier
    + Default pretty printer should print inner-class receiver
    parameters on constructors
    + Issue #3405 thread safety of pre/postprocessors (incl.
    breaking change to Processor with pre/post processor
    methods).
  * Developer Changes
    + chore(deps): update actions/checkout action to v3.0.1
    + official Apache Maven wrapper
    + chore(deps): update codecov/codecov-action action to v3
    + chore(deps): update dependency org.jacoco:jacoco-maven-plugin
    to v0.8.8
    + chore(deps): update dependency
    org.apache.maven.plugins:maven-clean-plugin to v3.2.0
    + chore(deps): update dependency
    org.apache.maven.plugins:maven-surefire-plugin to v3.0.0-m6
- Re-enable modules:
  javaparser-symbol-solver-{core,logic,model,testing}
- Add build dependency on mvn(org.javassist:javassist)
- Update summary and description
* Mon May 23 2022 fstrba@suse.com
- Upgrade to upstream version 3.24.2
  * Fixes:
    + Adding constructor descriptor
    + Fix issue #3491  Method has a multidimensional arrays argument
    in jar file. when call the method throw
    UnsolvedSymbolException
    + Fix issue #3218 GetSourceRoots() does not return all source
    roots
    + Bug in ArrayCreationExpr constructors
    + Fix issue 3440 Removing a node with LexicalPreservingPrinter
    causes UnsupportedOperationException
    + Improve unit test for BlockStmtContextResolutionTest
    + Improve Conditional Operator resolution [JLS 15.25]
    + Fix issue #3526 Variable or FieldDeclaration is not resolved
    correctly when another variable with the same name is
    declared in the same block
* Thu Mar 10 2022 fstrba@suse.com
- Upgrade to the latest version 3.24.0
  * A long list of fixes is to be found at https://github.com/
    /javaparser/javaparser/blob/master/changelog.md
  * Upgrade needed to be able to upgrade jctools and make them
    not depend hard on Java 8
* Tue Oct  1 2019 fstrba@suse.com
- Initial packaging of javaparser 3.3.5
